==> act-0.5.53.tar.gz: act-0.5.53/act_1/src/actMfcTestRunner/TreeHierarchyDlg.cpp <==
// TreeHierarchyDlg.cpp : implementation file
//

#include "stdafx.h"
#include "resource.h"
#include "TreeHierarchyDlg.h"
#include "TestRunnerModel.h"
#include "ResourceLoaders.h"
#include <algorithm>


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// TreeHierarchyDlg dialog


TreeHierarchyDlg::TreeHierarchyDlg(CWnd* pParent /*=NULL*/)
	: cdxCDynamicDialog(TreeHierarchyDlg::IDD, pParent)
  , m_selectedTest( NULL )
{
  ModifyFlags( flSWPCopyBits, 0 );      // anti-flickering option for resizing

	//{{AFX_DATA_INIT(TreeHierarchyDlg)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
}


void 
TreeHierarchyDlg::DoDataExchange(CDataExchange* pDX)
{
	cdxCDynamicDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(TreeHierarchyDlg)
	DDX_Control(pDX, IDC_TREE_TEST, m_treeTests);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(TreeHierarchyDlg, cdxCDynamicDialog)
	//{{AFX_MSG_MAP(TreeHierarchyDlg)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// TreeHierarchyDlg message handlers

void 
TreeHierarchyDlg::setRootTest(ITest *test)
{
    m_rootTest = test;
}

BOOL 
TreeHierarchyDlg::OnInitDialog() 
{
	cdxCDynamicDialog::OnInitDialog();
	
  fillTree();
  initializeLayout();
  RestoreWindowPosition( TestRunnerModel::settingKey, 
                         TestRunnerModel::settingBrowseDialogKey );
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}


void 
TreeHierarchyDlg::initializeLayout()
{
  // see DynamicWindow/doc for documentation
  AddSzControl( IDC_TREE_TEST, mdResize, mdResize );
  AddSzControl( IDOK, mdRepos, mdNone );
  AddSzControl( IDCANCEL, mdRepos, mdNone );
}


void 
TreeHierarchyDlg::fillTree()
{
  VERIFY( m_imageList.Create( _T("CPP_UNIT_TEST_RUNNER_IDB_TEST_TYPE"), 
                              16, 1, RGB( 255,0,255 ) ) );

  m_treeTests.SetImageList( &m_imageList, TVSIL_NORMAL );

  HTREEITEM hSuite = addTest( m_rootTest, TVI_ROOT );
  m_treeTests.Expand( hSuite, TVE_EXPAND );
}


HTREEITEM 
TreeHierarchyDlg::addTest(ITest *test, 
                          HTREEITEM hParent)
{
int testType = isSuite( test ) ? imgSuite : imgUnitTest;
  HTREEITEM hItem = m_treeTests.InsertItem( ITest_name(test),
                                            testType,
                                            testType,
                                            hParent );
  if ( hItem != NULL )
  {
    VERIFY( m_treeTests.SetItemData( hItem, (DWORD)test ) );
    if ( isSuite( test ) )
      addTestSuiteChildrenTo( test, hItem );
  }
return hItem;
}


void 
TreeHierarchyDlg::addTestSuiteChildrenTo(ITest *suite, 
                                         HTREEITEM hItemSuite)
{
#if 0
  Tests tests;
  int childIndex = 0;
  for ( ; childIndex < suite->getChildTestCount(); ++childIndex )
    tests.push_back( suite->getChildTestAt( childIndex ) );
  sortByName( tests );

  for ( childIndex = 0; childIndex < suite->getChildTestCount(); ++childIndex )
    addTest( suite->getChildTestAt( childIndex ), hItemSuite );
#endif
}

bool 
TreeHierarchyDlg::isSuite(ITest *test)
{
#if 0
  return ( test->getChildTestCount() > 0  ||    // suite with test
           test->countTestCases() == 0 );       // empty suite
#endif
    return false;
}


struct PredSortTest
{
  bool operator()( ITest *test1, ITest *test2 ) const
  {
    bool isTest1Suite = TreeHierarchyDlg::isSuite( test1 );
    bool isTest2Suite = TreeHierarchyDlg::isSuite( test2 );
    if ( isTest1Suite  &&  !isTest2Suite )
      return true;
    if ( isTest1Suite  &&  isTest2Suite )
    {
#if 0
      return test1->getName() < test2->getName();
#endif
    }
    return false;
  }
};

void 
TreeHierarchyDlg::sortByName(Tests &tests) const
{
#if 0
  std::stable_sort( tests.begin(), tests.end(), PredSortTest() );
#endif
}


void 
TreeHierarchyDlg::OnOK() 
{
  ITest *test = findSelectedTest();
  if ( test == NULL )
  {
    AfxMessageBox( loadCString(IDS_ERROR_SELECT_TEST), MB_OK );
    return;
  }
	
  m_selectedTest = test;
  storeDialogBounds();
	cdxCDynamicDialog::OnOK();
}


void 
TreeHierarchyDlg::OnCancel() 
{
  storeDialogBounds();
	cdxCDynamicDialog::OnCancel();
}


ITest* 
TreeHierarchyDlg::findSelectedTest()
{
#if 0
  HTREEITEM hItem = m_treeTests.GetSelectedItem();
  if ( hItem != NULL )
  {
    DWORD data;
    VERIFY( data = m_treeTests.GetItemData( hItem ) );
    return reinterpret_cast<CPPUNIT_NS::Test *>( data );
  }
#endif
  return NULL;
}


ITest* 
TreeHierarchyDlg::getSelectedTest() const
{
  return m_selectedTest;
}


void 
TreeHierarchyDlg::storeDialogBounds()
{
  StoreWindowPosition( TestRunnerModel::settingKey, 
                       TestRunnerModel::settingBrowseDialogKey );
}

==> act-0.5.54.tar.gz: act-0.5.54/act_1/src/actMfcTestRunner/TreeHierarchyDlg.cpp <==
// TreeHierarchyDlg.cpp : implementation file
//

#include "stdafx.h"
#include "resource.h"
#include "TreeHierarchyDlg.h"
#include "TestRunnerModel.h"
#include "ResourceLoaders.h"
#include <algorithm>


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// TreeHierarchyDlg dialog


TreeHierarchyDlg::TreeHierarchyDlg(CWnd* pParent /*=NULL*/)
	: cdxCDynamicDialog(TreeHierarchyDlg::IDD, pParent)
  , m_selectedTest( NULL )
{
  ModifyFlags( flSWPCopyBits, 0 );      // anti-flickering option for resizing

	//{{AFX_DATA_INIT(TreeHierarchyDlg)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
}


void 
TreeHierarchyDlg::DoDataExchange(CDataExchange* pDX)
{
	cdxCDynamicDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(TreeHierarchyDlg)
	DDX_Control(pDX, IDC_TREE_TEST, m_treeTests);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(TreeHierarchyDlg, cdxCDynamicDialog)
	//{{AFX_MSG_MAP(TreeHierarchyDlg)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// TreeHierarchyDlg message handlers

void 
TreeHierarchyDlg::setRootTest(ITest *test)
{
    m_rootTest = test;
}


BOOL 
TreeHierarchyDlg::OnInitDialog() 
{
	cdxCDynamicDialog::OnInitDialog();
	
  fillTree();
  initializeLayout();
  RestoreWindowPosition( TestRunnerModel::settingKey, 
                         TestRunnerModel::settingBrowseDialogKey );
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}


void 
TreeHierarchyDlg::initializeLayout()
{
  // see DynamicWindow/doc for documentation
  AddSzControl( IDC_TREE_TEST, mdResize, mdResize );
  AddSzControl( IDOK, mdRepos, mdNone );
  AddSzControl( IDCANCEL, mdRepos, mdNone );
}


void 
TreeHierarchyDlg::fillTree()
{
  VERIFY( m_imageList.Create( _T("ACT_TEST_RUNNER_IDB_TEST_TYPE"), 
                              16, 1, RGB( 255,0,255 ) ) );

  m_treeTests.SetImageList( &m_imageList, TVSIL_NORMAL );

  HTREEITEM hSuite = addTest( m_rootTest, TVI_ROOT );
  m_treeTests.Expand( hSuite, TVE_EXPAND );
}


HTREEITEM 
TreeHierarchyDlg::addTest(ITest *test, 
                          HTREEITEM hParent)
{
int testType = isSuite( test ) ? imgSuite : imgUnitTest;
  HTREEITEM hItem = m_treeTests.InsertItem( ITest_name(test),
                                            testType,
                                            testType,
                                            hParent );
  if ( hItem != NULL )
  {
    VERIFY( m_treeTests.SetItemData( hItem, (DWORD)test ) );
    if ( isSuite( test ) )
      addTestSuiteChildrenTo( test, hItem );
  }
return hItem;
}


void 
TreeHierarchyDlg::addTestSuiteChildrenTo(ITest *suite, 
                                         HTREEITEM hItemSuite)
{
  Tests tests;
  int childIndex = 0;
  for ( ; childIndex < ITest_getChildTestCount(suite); ++childIndex )
    tests.push_back( ITest_getChildTestAt(suite, childIndex ) );
  sortByName( tests );

  for ( childIndex = 0; childIndex < ITest_getChildTestCount(suite); ++childIndex )
    addTest( ITest_getChildTestAt(suite, childIndex ), hItemSuite );
}

bool 
TreeHierarchyDlg::isSuite(ITest *test)
{
  return ( ITest_getChildTestCount(test) > 0 || // suite with test
           ITest_countTestCases(test) == 0); // empty suite
}


struct PredSortTest
{    
  bool operator()( ITest *test1, ITest *test2 ) const
  {
    bool isTest1Suite = TreeHierarchyDlg::isSuite( test1 );
    bool isTest2Suite = TreeHierarchyDlg::isSuite( test2 );
    if ( isTest1Suite  &&  !isTest2Suite )
      return true;
    if ( isTest1Suite  &&  isTest2Suite )
    {        
        CString str1 = ITest_name(test1);
        CString str2 = ITest_name(test2);
        return str1 < str2;
   }
    return false;
  }
};

void 
TreeHierarchyDlg::sortByName(Tests &tests) const
{
  std::stable_sort( tests.begin(), tests.end(), PredSortTest() );
}


void 
TreeHierarchyDlg::OnOK() 
{
  ITest *test = findSelectedTest();
  if ( test == NULL )
  {
    AfxMessageBox( loadCString(IDS_ERROR_SELECT_TEST), MB_OK );
    return;
  }
	
  m_selectedTest = test;
  storeDialogBounds();
	cdxCDynamicDialog::OnOK();
}


void 
TreeHierarchyDlg::OnCancel() 
{
  storeDialogBounds();
	cdxCDynamicDialog::OnCancel();
}


ITest* 
TreeHierarchyDlg::findSelectedTest()
{
  HTREEITEM hItem = m_treeTests.GetSelectedItem();
  if ( hItem != NULL )
  {
    DWORD data;
    VERIFY( data = m_treeTests.GetItemData( hItem ) );
    return (ITest *)( data );
  }
  return NULL;
}


ITest* 
TreeHierarchyDlg::getSelectedTest() const
{
  return m_selectedTest;
}


void 
TreeHierarchyDlg::storeDialogBounds()
{
  StoreWindowPosition( TestRunnerModel::settingKey, 
                       TestRunnerModel::settingBrowseDialogKey );
}
